/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.ivy.osgi.core;

import java.net.URI;

public class BundleArtifact {

    private boolean source = false;

    private URI uri;

    private String format;

    public BundleArtifact(boolean source, URI uri, String format) {
        this.source = source;
        this.uri = uri;
        this.format = format;
    }

    public boolean isSource() {
        return source;
    }

    public URI getUri() {
        return uri;
    }

    public String getFormat() {
        return format;
    }

}
